
rm(list = ls())
source('tools.R')

# instalar librerias
library(svDialogs)
library(PBSadmb)
library(ellipse)
library(MASS)

m_list <- c("pella_base","pella_1","pella_2","pella_3")
file.rep <- (guiDlgList(m_list))

ss <- readList(paste(file.rep,'.rep', sep=''))
sw <- read.fit(file.rep)

# exploracion de parametros
bayes <- mcmc.plot('pella_base', 'pairs');
bayes <- mcmc.plot('pella_base','eggs');
bayes <- mcmc.plot('pella_base','acf');
bayes <- mcmc.plot('pella_base','trace');
bayes <- mcmc.plot('pella_base','dens');

ss$Estimated_catch[21] <- 2289

# Figura 1
x11()
ss$Estimated_cpue <- ss$Estimated_catch/(ss$Effort*ss$Avg_Effort_p)
plot(ss$years,ss$Observed_cpue,ann=FALSE, type="n")
abline(h=500, col=gray(.90))
lines(ss$years,ss$Estimated_cpue, col="green4", lty="solid", lwd=2.5)
points(ss$years,ss$Observed_cpue, bg="limegreen", pch=21, cex=1.3)

# Figura 2
x11()
plot(ss$years,ss$Observed_catch,ann=FALSE, type="n")
abline(h=500, col=gray(.90))
lines(ss$years,ss$Estimated_catch, col="green4", lty="solid", lwd=2.5)
points(ss$years,ss$Observed_catch, bg="limegreen", pch=21, cex=1.3)
title(main=NULL,
      xlab="Year",
      ylab="Desembarque (ton)",
      col.main="blue", col.lab=gray(.2),
      cex.main=1.2, cex.lab=1.0, font.main=4, font.lab=2)

# Figura 3
x11()
hist(bayes$Beta,30,main=NULL,
      xlab="Bo/K",
      ylab="Densidad",
      col.main="blue", col.lab=gray(.2),
      cex.main=1.2, cex.lab=1.0, font.main=4, font.lab=2)


#Figura 4
par(mfrow=c(2,1))
hist(bayes$Bact/bayes$Bo, xlim = c(0.05,0.2),main="",ylab="Densidad", col="green4", lty="solid", lwd=1.5, xlab = "Razon B/Bo")
boxplot(bayes$Bact/bayes$Bo,col="green4", lty="solid", lwd=1.5, horizontal = T, ylim = c(0.05,0.2))

#Figura 5
par(mfrow=c(1,2))
plot(ss$years,ss$Estimated_biomass[1:length(ss$years)],ann=FALSE, type="n", ylim = c(0, 55000))
lines(ss$years,ss$Estimated_biomass[1:length(ss$years)], col="green4", lty="dotted", lwd=1.5)
points(ss$years,ss$Estimated_biomass[1:length(ss$years)], bg="orange", pch=23, cex=1.2)
title(main="Biomasa Vulnerable",
      xlab="Year",
      ylab="Biomasa (ton)",
      col.main="black", col.lab=gray(.2),
      cex.main=1.2, cex.lab=1.0, font.main=4, font.lab=2)
plot(ss$years,ss$Estimated_biomass[1:length(ss$years)]/ss$Estimated_biomass[1],ann=FALSE, type="n", ylim=c(0,1))
abline(h=0.15, col=gray(.5), lty="dotted")
lines(ss$years,ss$Estimated_biomass[1:length(ss$years)]/ss$Estimated_biomass[1], col="green4", lty="dotted", lwd=1.5)
points(ss$years,ss$Estimated_biomass[1:length(ss$years)]/ss$Estimated_biomass[1], bg="white", pch=23, cex=1.2)
title(main="Reduccion BV",
      xlab="Year",
      ylab="BV/BVo",
      col.main="black", col.lab=gray(.2),
      cex.main=1.2, cex.lab=1.0, font.main=4, font.lab=2)

# Figura 6
x11()
plotcorr(mtcorr, type = "lower", diag = TRUE)


# Figura 7
posterior <- matrix(scan('pella_base.mcmc.out'),ncol = 8, byrow = TRUE)
x11()
plot(posterior[,2], posterior[,1]/1000, type='p', pch='.', cex=3, ylab="K", xlab="r")
points(sw$est[3],sw$est[6]/1000, bg="limegreen", pch=21, cex=1.3)
points(median(posterior[,2]),median(posterior[,1]/1000), bg="red", pch=21, cex=1.3)
points(mean(posterior[,2]),mean(posterior[,1]/1000), bg="blue", pch=21, cex=1.3)
#legend("topright",c('data','model','median','mean'),pty=3,col=c(1,'limegreen','red','blue'))

# Figura 8
x11()
par(mfrow=c(2,2))
hist(posterior[,1]/1000,50,main='K')
abline(v=sw$est[6]/1000,col = 'red')
hist(posterior[,2],50,main='r')
abline(v=sw$est[3],col = 'red')
hist(posterior[,3],50,main='q')
abline(v=sw$est[1],col = 'red')
hist(posterior[,4]/1000,80,main='Binit')
abline(v=exp(sw$est[4])/1000,col = 'red')

# Figura 9
mtcorr <- cor(posterior)
colnames(mtcorr) <- c('k','r','q','bint')
rownames(mtcorr) <- c('k','r','q','bint')
x11()
plotcorr(mtcorr, diag = TRUE)


# Figura 10
sigma <- sw$cov
mu <- sw$est
asymptotic <- mvrnorm(n=2200, mu, Sigma)

x11()
par(mfrow=c(2,2))
hist(posterior[,1]/1000,50,main='mcmc K')
hist(asymptotic[,6],50,main='normal asymptotic  K')
hist(posterior[,2],50,main='mcmc r')
hist(asymptotic[,3],50,main='normal asymptotic  r')


